@@ -286,7 +286,7 @@ class ResultRecorder(BaseResultHandler):
         # gets created that the timestamp on the progress result is less
         # than the timestamp of when the result processor actually
         # processes that initial queued result. So this will avoid
-        # negative progress being displayed or zero divison occuring.
+        # negative progress being displayed or zero divison occurring.
         if result.timestamp > self.start_time:
             self.bytes_transfer_speed = self.bytes_transferred / (
                 result.timestamp - self.start_time)
@@ -554,6 +554,12 @@ class ResultPrinter(BaseResultHandler):
             uni_print(self._adjust_statement_padding(''), self._out_file)
 
 
+class NoProgressResultPrinter(ResultPrinter):
+    """A result printer that doesn't print progress"""
+    def _print_progress(self, **kwargs):
+        pass
+
+
 class OnlyShowErrorsResultPrinter(ResultPrinter):
     """A result printer that only prints out errors"""
     def _print_progress(self, **kwargs):
