@@ -30,7 +30,7 @@ from awscli.customizations.s3.filters import create_filter
 from awscli.customizations.s3.s3handler import S3TransferHandlerFactory
 from awscli.customizations.s3.utils import find_bucket_key, AppendFilter, \
     find_dest_path_comp_key, human_readable_size, \
-    RequestParamsMapper, split_s3_bucket_key
+    RequestParamsMapper, split_s3_bucket_key, block_unsupported_resources
 from awscli.customizations.utils import uni_print
 from awscli.customizations.s3.syncstrategy.base import MissingFileSync, \
     SizeAndLastModifiedSync, NeverSync
@@ -420,7 +420,7 @@ REQUEST_PAYER = {
     'name': 'request-payer', 'choices': ['requester'],
     'nargs': '?', 'const': 'requester',
     'help_text': (
-        'Confirms that the requester knows that she or he will be charged '
+        'Confirms that the requester knows that they will be charged '
         'for the request. Bucket owners need not specify this parameter in '
         'their requests. Documentation on downloading objects from requester '
         'pays buckets can be found at '
@@ -636,11 +636,12 @@ class WebsiteCommand(S3Command):
         # bucketname
         #
         # We also strip off the trailing slash if a user
-        # accidently appends a slash.
+        # accidentally appends a slash.
         if path.startswith('s3://'):
             path = path[5:]
         if path.endswith('/'):
             path = path[:-1]
+        block_unsupported_resources(path)
         return path
 
 
